#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP0InBra_aB_f__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp211;
fp211 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp210;
fp210 = fp211 * src4[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp213;
fp213 = inteval->WP_z[vi] * src1[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp214;
fp214 = inteval->PA_z[vi] * src0[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp212;
fp212 = fp214 + fp213;
LIBINT2_REALTYPE fp209;
fp209 = fp212 + fp210;
target[((hsi*60+29)*1+lsi)*1] = fp209;
LIBINT2_REALTYPE fp216;
fp216 = inteval->oo2ze[vi] * src4[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp218;
fp218 = inteval->WP_z[vi] * src1[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp219;
fp219 = inteval->PA_z[vi] * src0[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp217;
fp217 = fp219 + fp218;
LIBINT2_REALTYPE fp215;
fp215 = fp217 + fp216;
target[((hsi*60+28)*1+lsi)*1] = fp215;
LIBINT2_REALTYPE fp221;
fp221 = inteval->WP_z[vi] * src1[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp222;
fp222 = inteval->PA_z[vi] * src0[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp220;
fp220 = fp222 + fp221;
target[((hsi*60+27)*1+lsi)*1] = fp220;
LIBINT2_REALTYPE fp224;
fp224 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp226;
fp226 = inteval->WP_z[vi] * src1[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp227;
fp227 = inteval->PA_z[vi] * src0[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp225;
fp225 = fp227 + fp226;
LIBINT2_REALTYPE fp223;
fp223 = fp225 + fp224;
target[((hsi*60+26)*1+lsi)*1] = fp223;
LIBINT2_REALTYPE fp229;
fp229 = inteval->WP_z[vi] * src1[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp230;
fp230 = inteval->PA_z[vi] * src0[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp228;
fp228 = fp230 + fp229;
target[((hsi*60+25)*1+lsi)*1] = fp228;
LIBINT2_REALTYPE fp232;
fp232 = inteval->WP_z[vi] * src1[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp233;
fp233 = inteval->PA_z[vi] * src0[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp231;
fp231 = fp233 + fp232;
target[((hsi*60+24)*1+lsi)*1] = fp231;
LIBINT2_REALTYPE fp324;
fp324 = inteval->roz[vi] * src3[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp323;
fp323 = src2[((hsi*18+5)*1+lsi)*1] - fp324;
LIBINT2_REALTYPE fp235;
fp235 = inteval->oo2z[vi] * fp323;
LIBINT2_REALTYPE fp237;
fp237 = inteval->WP_y[vi] * src1[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp238;
fp238 = inteval->PA_y[vi] * src0[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp236;
fp236 = fp238 + fp237;
LIBINT2_REALTYPE fp234;
fp234 = fp236 + fp235;
target[((hsi*60+23)*1+lsi)*1] = fp234;
LIBINT2_REALTYPE fp240;
fp240 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp332;
fp332 = inteval->roz[vi] * src3[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp331;
fp331 = src2[((hsi*18+4)*1+lsi)*1] - fp332;
LIBINT2_REALTYPE fp242;
fp242 = inteval->oo2z[vi] * fp331;
LIBINT2_REALTYPE fp244;
fp244 = inteval->WP_y[vi] * src1[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp245;
fp245 = inteval->PA_y[vi] * src0[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp243;
fp243 = fp245 + fp244;
LIBINT2_REALTYPE fp241;
fp241 = fp243 + fp242;
LIBINT2_REALTYPE fp239;
fp239 = fp241 + fp240;
target[((hsi*60+22)*1+lsi)*1] = fp239;
LIBINT2_REALTYPE fp248;
fp248 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp247;
fp247 = fp248 * src4[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp340;
fp340 = inteval->roz[vi] * src3[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp339;
fp339 = src2[((hsi*18+3)*1+lsi)*1] - fp340;
LIBINT2_REALTYPE fp250;
fp250 = inteval->oo2z[vi] * fp339;
LIBINT2_REALTYPE fp252;
fp252 = inteval->WP_y[vi] * src1[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp253;
fp253 = inteval->PA_y[vi] * src0[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp251;
fp251 = fp253 + fp252;
LIBINT2_REALTYPE fp249;
fp249 = fp251 + fp250;
LIBINT2_REALTYPE fp246;
fp246 = fp249 + fp247;
target[((hsi*60+21)*1+lsi)*1] = fp246;
LIBINT2_REALTYPE fp350;
fp350 = inteval->roz[vi] * src3[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp349;
fp349 = src2[((hsi*18+2)*1+lsi)*1] - fp350;
LIBINT2_REALTYPE fp255;
fp255 = inteval->oo2z[vi] * fp349;
LIBINT2_REALTYPE fp257;
fp257 = inteval->WP_y[vi] * src1[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp258;
fp258 = inteval->PA_y[vi] * src0[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp256;
fp256 = fp258 + fp257;
LIBINT2_REALTYPE fp254;
fp254 = fp256 + fp255;
target[((hsi*60+20)*1+lsi)*1] = fp254;
LIBINT2_REALTYPE fp260;
fp260 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp360;
fp360 = inteval->roz[vi] * src3[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp359;
fp359 = src2[((hsi*18+1)*1+lsi)*1] - fp360;
LIBINT2_REALTYPE fp262;
fp262 = inteval->oo2z[vi] * fp359;
LIBINT2_REALTYPE fp264;
fp264 = inteval->WP_y[vi] * src1[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp265;
fp265 = inteval->PA_y[vi] * src0[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp263;
fp263 = fp265 + fp264;
LIBINT2_REALTYPE fp261;
fp261 = fp263 + fp262;
LIBINT2_REALTYPE fp259;
fp259 = fp261 + fp260;
target[((hsi*60+19)*1+lsi)*1] = fp259;
LIBINT2_REALTYPE fp371;
fp371 = inteval->roz[vi] * src3[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp370;
fp370 = src2[((hsi*18+0)*1+lsi)*1] - fp371;
LIBINT2_REALTYPE fp267;
fp267 = inteval->oo2z[vi] * fp370;
LIBINT2_REALTYPE fp269;
fp269 = inteval->WP_y[vi] * src1[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp270;
fp270 = inteval->PA_y[vi] * src0[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp268;
fp268 = fp270 + fp269;
LIBINT2_REALTYPE fp266;
fp266 = fp268 + fp267;
target[((hsi*60+18)*1+lsi)*1] = fp266;
LIBINT2_REALTYPE fp273;
fp273 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp272;
fp272 = fp273 * src4[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp275;
fp275 = inteval->WP_z[vi] * src1[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp276;
fp276 = inteval->PA_z[vi] * src0[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp274;
fp274 = fp276 + fp275;
LIBINT2_REALTYPE fp271;
fp271 = fp274 + fp272;
target[((hsi*60+17)*1+lsi)*1] = fp271;
LIBINT2_REALTYPE fp278;
fp278 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp280;
fp280 = inteval->WP_z[vi] * src1[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp281;
fp281 = inteval->PA_z[vi] * src0[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp279;
fp279 = fp281 + fp280;
LIBINT2_REALTYPE fp277;
fp277 = fp279 + fp278;
target[((hsi*60+16)*1+lsi)*1] = fp277;
LIBINT2_REALTYPE fp283;
fp283 = inteval->WP_z[vi] * src1[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp284;
fp284 = inteval->PA_z[vi] * src0[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp282;
fp282 = fp284 + fp283;
target[((hsi*60+15)*1+lsi)*1] = fp282;
LIBINT2_REALTYPE fp286;
fp286 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp288;
fp288 = inteval->WP_z[vi] * src1[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp289;
fp289 = inteval->PA_z[vi] * src0[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp287;
fp287 = fp289 + fp288;
LIBINT2_REALTYPE fp285;
fp285 = fp287 + fp286;
target[((hsi*60+14)*1+lsi)*1] = fp285;
LIBINT2_REALTYPE fp291;
fp291 = inteval->WP_z[vi] * src1[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp292;
fp292 = inteval->PA_z[vi] * src0[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp290;
fp290 = fp292 + fp291;
target[((hsi*60+13)*1+lsi)*1] = fp290;
LIBINT2_REALTYPE fp294;
fp294 = inteval->WP_z[vi] * src1[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp295;
fp295 = inteval->PA_z[vi] * src0[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp293;
fp293 = fp295 + fp294;
target[((hsi*60+12)*1+lsi)*1] = fp293;
LIBINT2_REALTYPE fp297;
fp297 = inteval->WP_y[vi] * src1[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp298;
fp298 = inteval->PA_y[vi] * src0[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp296;
fp296 = fp298 + fp297;
target[((hsi*60+11)*1+lsi)*1] = fp296;
LIBINT2_REALTYPE fp300;
fp300 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp302;
fp302 = inteval->WP_y[vi] * src1[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp303;
fp303 = inteval->PA_y[vi] * src0[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp301;
fp301 = fp303 + fp302;
LIBINT2_REALTYPE fp299;
fp299 = fp301 + fp300;
target[((hsi*60+10)*1+lsi)*1] = fp299;
LIBINT2_REALTYPE fp306;
fp306 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp305;
fp305 = fp306 * src4[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp308;
fp308 = inteval->WP_y[vi] * src1[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp309;
fp309 = inteval->PA_y[vi] * src0[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp307;
fp307 = fp309 + fp308;
LIBINT2_REALTYPE fp304;
fp304 = fp307 + fp305;
target[((hsi*60+9)*1+lsi)*1] = fp304;
LIBINT2_REALTYPE fp311;
fp311 = inteval->WP_y[vi] * src1[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp312;
fp312 = inteval->PA_y[vi] * src0[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp310;
fp310 = fp312 + fp311;
target[((hsi*60+8)*1+lsi)*1] = fp310;
LIBINT2_REALTYPE fp314;
fp314 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp316;
fp316 = inteval->WP_y[vi] * src1[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp317;
fp317 = inteval->PA_y[vi] * src0[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp315;
fp315 = fp317 + fp316;
LIBINT2_REALTYPE fp313;
fp313 = fp315 + fp314;
target[((hsi*60+7)*1+lsi)*1] = fp313;
LIBINT2_REALTYPE fp319;
fp319 = inteval->WP_y[vi] * src1[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp320;
fp320 = inteval->PA_y[vi] * src0[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp318;
fp318 = fp320 + fp319;
target[((hsi*60+6)*1+lsi)*1] = fp318;
LIBINT2_REALTYPE fp325;
fp325 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp322;
fp322 = fp325 * fp323;
LIBINT2_REALTYPE fp327;
fp327 = inteval->WP_x[vi] * src1[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp328;
fp328 = inteval->PA_x[vi] * src0[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp326;
fp326 = fp328 + fp327;
LIBINT2_REALTYPE fp321;
fp321 = fp326 + fp322;
target[((hsi*60+5)*1+lsi)*1] = fp321;
LIBINT2_REALTYPE fp333;
fp333 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp330;
fp330 = fp333 * fp331;
LIBINT2_REALTYPE fp335;
fp335 = inteval->WP_x[vi] * src1[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp336;
fp336 = inteval->PA_x[vi] * src0[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp334;
fp334 = fp336 + fp335;
LIBINT2_REALTYPE fp329;
fp329 = fp334 + fp330;
target[((hsi*60+4)*1+lsi)*1] = fp329;
LIBINT2_REALTYPE fp341;
fp341 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp338;
fp338 = fp341 * fp339;
LIBINT2_REALTYPE fp343;
fp343 = inteval->WP_x[vi] * src1[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp344;
fp344 = inteval->PA_x[vi] * src0[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp342;
fp342 = fp344 + fp343;
LIBINT2_REALTYPE fp337;
fp337 = fp342 + fp338;
target[((hsi*60+3)*1+lsi)*1] = fp337;
LIBINT2_REALTYPE fp346;
fp346 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp351;
fp351 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp348;
fp348 = fp351 * fp349;
LIBINT2_REALTYPE fp353;
fp353 = inteval->WP_x[vi] * src1[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp354;
fp354 = inteval->PA_x[vi] * src0[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp352;
fp352 = fp354 + fp353;
LIBINT2_REALTYPE fp347;
fp347 = fp352 + fp348;
LIBINT2_REALTYPE fp345;
fp345 = fp347 + fp346;
target[((hsi*60+2)*1+lsi)*1] = fp345;
LIBINT2_REALTYPE fp356;
fp356 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp361;
fp361 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp358;
fp358 = fp361 * fp359;
LIBINT2_REALTYPE fp363;
fp363 = inteval->WP_x[vi] * src1[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp364;
fp364 = inteval->PA_x[vi] * src0[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp362;
fp362 = fp364 + fp363;
LIBINT2_REALTYPE fp357;
fp357 = fp362 + fp358;
LIBINT2_REALTYPE fp355;
fp355 = fp357 + fp356;
target[((hsi*60+1)*1+lsi)*1] = fp355;
LIBINT2_REALTYPE fp367;
fp367 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp366;
fp366 = fp367 * src4[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp372;
fp372 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp369;
fp369 = fp372 * fp370;
LIBINT2_REALTYPE fp374;
fp374 = inteval->WP_x[vi] * src1[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp375;
fp375 = inteval->PA_x[vi] * src0[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp373;
fp373 = fp375 + fp374;
LIBINT2_REALTYPE fp368;
fp368 = fp373 + fp369;
LIBINT2_REALTYPE fp365;
fp365 = fp368 + fp366;
target[((hsi*60+0)*1+lsi)*1] = fp365;
LIBINT2_REALTYPE fp2;
fp2 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp1;
fp1 = fp2 * src4[((hsi*18+17)*1+lsi)*1];
LIBINT2_REALTYPE fp6;
fp6 = inteval->roz[vi] * src3[((hsi*18+17)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = src2[((hsi*18+17)*1+lsi)*1] - fp6;
LIBINT2_REALTYPE fp7;
fp7 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp4;
fp4 = fp7 * fp5;
LIBINT2_REALTYPE fp9;
fp9 = inteval->WP_z[vi] * src1[((hsi*36+35)*1+lsi)*1];
LIBINT2_REALTYPE fp10;
fp10 = inteval->PA_z[vi] * src0[((hsi*36+35)*1+lsi)*1];
LIBINT2_REALTYPE fp8;
fp8 = fp10 + fp9;
LIBINT2_REALTYPE fp3;
fp3 = fp8 + fp4;
LIBINT2_REALTYPE fp0;
fp0 = fp3 + fp1;
target[((hsi*60+59)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp12;
fp12 = inteval->oo2ze[vi] * src4[((hsi*18+16)*1+lsi)*1];
LIBINT2_REALTYPE fp16;
fp16 = inteval->roz[vi] * src3[((hsi*18+16)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = src2[((hsi*18+16)*1+lsi)*1] - fp16;
LIBINT2_REALTYPE fp17;
fp17 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp14;
fp14 = fp17 * fp15;
LIBINT2_REALTYPE fp19;
fp19 = inteval->WP_z[vi] * src1[((hsi*36+34)*1+lsi)*1];
LIBINT2_REALTYPE fp20;
fp20 = inteval->PA_z[vi] * src0[((hsi*36+34)*1+lsi)*1];
LIBINT2_REALTYPE fp18;
fp18 = fp20 + fp19;
LIBINT2_REALTYPE fp13;
fp13 = fp18 + fp14;
LIBINT2_REALTYPE fp11;
fp11 = fp13 + fp12;
target[((hsi*60+58)*1+lsi)*1] = fp11;
LIBINT2_REALTYPE fp24;
fp24 = inteval->roz[vi] * src3[((hsi*18+15)*1+lsi)*1];
LIBINT2_REALTYPE fp23;
fp23 = src2[((hsi*18+15)*1+lsi)*1] - fp24;
LIBINT2_REALTYPE fp25;
fp25 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp22;
fp22 = fp25 * fp23;
LIBINT2_REALTYPE fp27;
fp27 = inteval->WP_z[vi] * src1[((hsi*36+33)*1+lsi)*1];
LIBINT2_REALTYPE fp28;
fp28 = inteval->PA_z[vi] * src0[((hsi*36+33)*1+lsi)*1];
LIBINT2_REALTYPE fp26;
fp26 = fp28 + fp27;
LIBINT2_REALTYPE fp21;
fp21 = fp26 + fp22;
target[((hsi*60+57)*1+lsi)*1] = fp21;
LIBINT2_REALTYPE fp30;
fp30 = inteval->oo2ze[vi] * src4[((hsi*18+15)*1+lsi)*1];
LIBINT2_REALTYPE fp34;
fp34 = inteval->roz[vi] * src3[((hsi*18+14)*1+lsi)*1];
LIBINT2_REALTYPE fp33;
fp33 = src2[((hsi*18+14)*1+lsi)*1] - fp34;
LIBINT2_REALTYPE fp35;
fp35 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp32;
fp32 = fp35 * fp33;
LIBINT2_REALTYPE fp37;
fp37 = inteval->WP_z[vi] * src1[((hsi*36+32)*1+lsi)*1];
LIBINT2_REALTYPE fp38;
fp38 = inteval->PA_z[vi] * src0[((hsi*36+32)*1+lsi)*1];
LIBINT2_REALTYPE fp36;
fp36 = fp38 + fp37;
LIBINT2_REALTYPE fp31;
fp31 = fp36 + fp32;
LIBINT2_REALTYPE fp29;
fp29 = fp31 + fp30;
target[((hsi*60+56)*1+lsi)*1] = fp29;
LIBINT2_REALTYPE fp42;
fp42 = inteval->roz[vi] * src3[((hsi*18+13)*1+lsi)*1];
LIBINT2_REALTYPE fp41;
fp41 = src2[((hsi*18+13)*1+lsi)*1] - fp42;
LIBINT2_REALTYPE fp43;
fp43 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp40;
fp40 = fp43 * fp41;
LIBINT2_REALTYPE fp45;
fp45 = inteval->WP_z[vi] * src1[((hsi*36+31)*1+lsi)*1];
LIBINT2_REALTYPE fp46;
fp46 = inteval->PA_z[vi] * src0[((hsi*36+31)*1+lsi)*1];
LIBINT2_REALTYPE fp44;
fp44 = fp46 + fp45;
LIBINT2_REALTYPE fp39;
fp39 = fp44 + fp40;
target[((hsi*60+55)*1+lsi)*1] = fp39;
LIBINT2_REALTYPE fp50;
fp50 = inteval->roz[vi] * src3[((hsi*18+12)*1+lsi)*1];
LIBINT2_REALTYPE fp49;
fp49 = src2[((hsi*18+12)*1+lsi)*1] - fp50;
LIBINT2_REALTYPE fp51;
fp51 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp48;
fp48 = fp51 * fp49;
LIBINT2_REALTYPE fp53;
fp53 = inteval->WP_z[vi] * src1[((hsi*36+30)*1+lsi)*1];
LIBINT2_REALTYPE fp54;
fp54 = inteval->PA_z[vi] * src0[((hsi*36+30)*1+lsi)*1];
LIBINT2_REALTYPE fp52;
fp52 = fp54 + fp53;
LIBINT2_REALTYPE fp47;
fp47 = fp52 + fp48;
target[((hsi*60+54)*1+lsi)*1] = fp47;
LIBINT2_REALTYPE fp57;
fp57 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp56;
fp56 = fp57 * src4[((hsi*18+14)*1+lsi)*1];
LIBINT2_REALTYPE fp120;
fp120 = inteval->roz[vi] * src3[((hsi*18+11)*1+lsi)*1];
LIBINT2_REALTYPE fp119;
fp119 = src2[((hsi*18+11)*1+lsi)*1] - fp120;
LIBINT2_REALTYPE fp59;
fp59 = inteval->oo2z[vi] * fp119;
LIBINT2_REALTYPE fp61;
fp61 = inteval->WP_z[vi] * src1[((hsi*36+29)*1+lsi)*1];
LIBINT2_REALTYPE fp62;
fp62 = inteval->PA_z[vi] * src0[((hsi*36+29)*1+lsi)*1];
LIBINT2_REALTYPE fp60;
fp60 = fp62 + fp61;
LIBINT2_REALTYPE fp58;
fp58 = fp60 + fp59;
LIBINT2_REALTYPE fp55;
fp55 = fp58 + fp56;
target[((hsi*60+53)*1+lsi)*1] = fp55;
LIBINT2_REALTYPE fp64;
fp64 = inteval->oo2ze[vi] * src4[((hsi*18+13)*1+lsi)*1];
LIBINT2_REALTYPE fp130;
fp130 = inteval->roz[vi] * src3[((hsi*18+10)*1+lsi)*1];
LIBINT2_REALTYPE fp129;
fp129 = src2[((hsi*18+10)*1+lsi)*1] - fp130;
LIBINT2_REALTYPE fp66;
fp66 = inteval->oo2z[vi] * fp129;
LIBINT2_REALTYPE fp68;
fp68 = inteval->WP_z[vi] * src1[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp69;
fp69 = inteval->PA_z[vi] * src0[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp67;
fp67 = fp69 + fp68;
LIBINT2_REALTYPE fp65;
fp65 = fp67 + fp66;
LIBINT2_REALTYPE fp63;
fp63 = fp65 + fp64;
target[((hsi*60+52)*1+lsi)*1] = fp63;
LIBINT2_REALTYPE fp141;
fp141 = inteval->roz[vi] * src3[((hsi*18+9)*1+lsi)*1];
LIBINT2_REALTYPE fp140;
fp140 = src2[((hsi*18+9)*1+lsi)*1] - fp141;
LIBINT2_REALTYPE fp71;
fp71 = inteval->oo2z[vi] * fp140;
LIBINT2_REALTYPE fp73;
fp73 = inteval->WP_z[vi] * src1[((hsi*36+27)*1+lsi)*1];
LIBINT2_REALTYPE fp74;
fp74 = inteval->PA_z[vi] * src0[((hsi*36+27)*1+lsi)*1];
LIBINT2_REALTYPE fp72;
fp72 = fp74 + fp73;
LIBINT2_REALTYPE fp70;
fp70 = fp72 + fp71;
target[((hsi*60+51)*1+lsi)*1] = fp70;
LIBINT2_REALTYPE fp76;
fp76 = inteval->oo2ze[vi] * src4[((hsi*18+12)*1+lsi)*1];
LIBINT2_REALTYPE fp149;
fp149 = inteval->roz[vi] * src3[((hsi*18+8)*1+lsi)*1];
LIBINT2_REALTYPE fp148;
fp148 = src2[((hsi*18+8)*1+lsi)*1] - fp149;
LIBINT2_REALTYPE fp78;
fp78 = inteval->oo2z[vi] * fp148;
LIBINT2_REALTYPE fp80;
fp80 = inteval->WP_z[vi] * src1[((hsi*36+26)*1+lsi)*1];
LIBINT2_REALTYPE fp81;
fp81 = inteval->PA_z[vi] * src0[((hsi*36+26)*1+lsi)*1];
LIBINT2_REALTYPE fp79;
fp79 = fp81 + fp80;
LIBINT2_REALTYPE fp77;
fp77 = fp79 + fp78;
LIBINT2_REALTYPE fp75;
fp75 = fp77 + fp76;
target[((hsi*60+50)*1+lsi)*1] = fp75;
LIBINT2_REALTYPE fp159;
fp159 = inteval->roz[vi] * src3[((hsi*18+7)*1+lsi)*1];
LIBINT2_REALTYPE fp158;
fp158 = src2[((hsi*18+7)*1+lsi)*1] - fp159;
LIBINT2_REALTYPE fp83;
fp83 = inteval->oo2z[vi] * fp158;
LIBINT2_REALTYPE fp85;
fp85 = inteval->WP_z[vi] * src1[((hsi*36+25)*1+lsi)*1];
LIBINT2_REALTYPE fp86;
fp86 = inteval->PA_z[vi] * src0[((hsi*36+25)*1+lsi)*1];
LIBINT2_REALTYPE fp84;
fp84 = fp86 + fp85;
LIBINT2_REALTYPE fp82;
fp82 = fp84 + fp83;
target[((hsi*60+49)*1+lsi)*1] = fp82;
LIBINT2_REALTYPE fp167;
fp167 = inteval->roz[vi] * src3[((hsi*18+6)*1+lsi)*1];
LIBINT2_REALTYPE fp166;
fp166 = src2[((hsi*18+6)*1+lsi)*1] - fp167;
LIBINT2_REALTYPE fp88;
fp88 = inteval->oo2z[vi] * fp166;
LIBINT2_REALTYPE fp90;
fp90 = inteval->WP_z[vi] * src1[((hsi*36+24)*1+lsi)*1];
LIBINT2_REALTYPE fp91;
fp91 = inteval->PA_z[vi] * src0[((hsi*36+24)*1+lsi)*1];
LIBINT2_REALTYPE fp89;
fp89 = fp91 + fp90;
LIBINT2_REALTYPE fp87;
fp87 = fp89 + fp88;
target[((hsi*60+48)*1+lsi)*1] = fp87;
LIBINT2_REALTYPE fp94;
fp94 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp93;
fp93 = fp94 * src4[((hsi*18+11)*1+lsi)*1];
LIBINT2_REALTYPE fp96;
fp96 = inteval->WP_z[vi] * src1[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp97;
fp97 = inteval->PA_z[vi] * src0[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp95;
fp95 = fp97 + fp96;
LIBINT2_REALTYPE fp92;
fp92 = fp95 + fp93;
target[((hsi*60+47)*1+lsi)*1] = fp92;
LIBINT2_REALTYPE fp99;
fp99 = inteval->oo2ze[vi] * src4[((hsi*18+10)*1+lsi)*1];
LIBINT2_REALTYPE fp101;
fp101 = inteval->WP_z[vi] * src1[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp102;
fp102 = inteval->PA_z[vi] * src0[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp100;
fp100 = fp102 + fp101;
LIBINT2_REALTYPE fp98;
fp98 = fp100 + fp99;
target[((hsi*60+46)*1+lsi)*1] = fp98;
LIBINT2_REALTYPE fp104;
fp104 = inteval->WP_z[vi] * src1[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp105;
fp105 = inteval->PA_z[vi] * src0[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = fp105 + fp104;
target[((hsi*60+45)*1+lsi)*1] = fp103;
LIBINT2_REALTYPE fp107;
fp107 = inteval->oo2ze[vi] * src4[((hsi*18+9)*1+lsi)*1];
LIBINT2_REALTYPE fp109;
fp109 = inteval->WP_z[vi] * src1[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp110;
fp110 = inteval->PA_z[vi] * src0[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp108;
fp108 = fp110 + fp109;
LIBINT2_REALTYPE fp106;
fp106 = fp108 + fp107;
target[((hsi*60+44)*1+lsi)*1] = fp106;
LIBINT2_REALTYPE fp112;
fp112 = inteval->WP_z[vi] * src1[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp113;
fp113 = inteval->PA_z[vi] * src0[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp111;
fp111 = fp113 + fp112;
target[((hsi*60+43)*1+lsi)*1] = fp111;
LIBINT2_REALTYPE fp115;
fp115 = inteval->WP_z[vi] * src1[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp116;
fp116 = inteval->PA_z[vi] * src0[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp114;
fp114 = fp116 + fp115;
target[((hsi*60+42)*1+lsi)*1] = fp114;
LIBINT2_REALTYPE fp121;
fp121 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp118;
fp118 = fp121 * fp119;
LIBINT2_REALTYPE fp123;
fp123 = inteval->WP_y[vi] * src1[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp124;
fp124 = inteval->PA_y[vi] * src0[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp122;
fp122 = fp124 + fp123;
LIBINT2_REALTYPE fp117;
fp117 = fp122 + fp118;
target[((hsi*60+41)*1+lsi)*1] = fp117;
LIBINT2_REALTYPE fp126;
fp126 = inteval->oo2ze[vi] * src4[((hsi*18+11)*1+lsi)*1];
LIBINT2_REALTYPE fp131;
fp131 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp128;
fp128 = fp131 * fp129;
LIBINT2_REALTYPE fp133;
fp133 = inteval->WP_y[vi] * src1[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp134;
fp134 = inteval->PA_y[vi] * src0[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp132;
fp132 = fp134 + fp133;
LIBINT2_REALTYPE fp127;
fp127 = fp132 + fp128;
LIBINT2_REALTYPE fp125;
fp125 = fp127 + fp126;
target[((hsi*60+40)*1+lsi)*1] = fp125;
LIBINT2_REALTYPE fp137;
fp137 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp136;
fp136 = fp137 * src4[((hsi*18+10)*1+lsi)*1];
LIBINT2_REALTYPE fp142;
fp142 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp139;
fp139 = fp142 * fp140;
LIBINT2_REALTYPE fp144;
fp144 = inteval->WP_y[vi] * src1[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp145;
fp145 = inteval->PA_y[vi] * src0[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp143;
fp143 = fp145 + fp144;
LIBINT2_REALTYPE fp138;
fp138 = fp143 + fp139;
LIBINT2_REALTYPE fp135;
fp135 = fp138 + fp136;
target[((hsi*60+39)*1+lsi)*1] = fp135;
LIBINT2_REALTYPE fp150;
fp150 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp147;
fp147 = fp150 * fp148;
LIBINT2_REALTYPE fp152;
fp152 = inteval->WP_y[vi] * src1[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp153;
fp153 = inteval->PA_y[vi] * src0[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp151;
fp151 = fp153 + fp152;
LIBINT2_REALTYPE fp146;
fp146 = fp151 + fp147;
target[((hsi*60+38)*1+lsi)*1] = fp146;
LIBINT2_REALTYPE fp155;
fp155 = inteval->oo2ze[vi] * src4[((hsi*18+9)*1+lsi)*1];
LIBINT2_REALTYPE fp160;
fp160 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp157;
fp157 = fp160 * fp158;
LIBINT2_REALTYPE fp162;
fp162 = inteval->WP_y[vi] * src1[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp163;
fp163 = inteval->PA_y[vi] * src0[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp161;
fp161 = fp163 + fp162;
LIBINT2_REALTYPE fp156;
fp156 = fp161 + fp157;
LIBINT2_REALTYPE fp154;
fp154 = fp156 + fp155;
target[((hsi*60+37)*1+lsi)*1] = fp154;
LIBINT2_REALTYPE fp168;
fp168 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp165;
fp165 = fp168 * fp166;
LIBINT2_REALTYPE fp170;
fp170 = inteval->WP_y[vi] * src1[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp171;
fp171 = inteval->PA_y[vi] * src0[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp169;
fp169 = fp171 + fp170;
LIBINT2_REALTYPE fp164;
fp164 = fp169 + fp165;
target[((hsi*60+36)*1+lsi)*1] = fp164;
LIBINT2_REALTYPE fp174;
fp174 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp173;
fp173 = fp174 * src4[((hsi*18+8)*1+lsi)*1];
LIBINT2_REALTYPE fp176;
fp176 = inteval->oo2z[vi] * fp323;
LIBINT2_REALTYPE fp178;
fp178 = inteval->WP_z[vi] * src1[((hsi*36+17)*1+lsi)*1];
LIBINT2_REALTYPE fp179;
fp179 = inteval->PA_z[vi] * src0[((hsi*36+17)*1+lsi)*1];
LIBINT2_REALTYPE fp177;
fp177 = fp179 + fp178;
LIBINT2_REALTYPE fp175;
fp175 = fp177 + fp176;
LIBINT2_REALTYPE fp172;
fp172 = fp175 + fp173;
target[((hsi*60+35)*1+lsi)*1] = fp172;
LIBINT2_REALTYPE fp181;
fp181 = inteval->oo2ze[vi] * src4[((hsi*18+7)*1+lsi)*1];
LIBINT2_REALTYPE fp183;
fp183 = inteval->oo2z[vi] * fp331;
LIBINT2_REALTYPE fp185;
fp185 = inteval->WP_z[vi] * src1[((hsi*36+16)*1+lsi)*1];
LIBINT2_REALTYPE fp186;
fp186 = inteval->PA_z[vi] * src0[((hsi*36+16)*1+lsi)*1];
LIBINT2_REALTYPE fp184;
fp184 = fp186 + fp185;
LIBINT2_REALTYPE fp182;
fp182 = fp184 + fp183;
LIBINT2_REALTYPE fp180;
fp180 = fp182 + fp181;
target[((hsi*60+34)*1+lsi)*1] = fp180;
LIBINT2_REALTYPE fp188;
fp188 = inteval->oo2z[vi] * fp339;
LIBINT2_REALTYPE fp190;
fp190 = inteval->WP_z[vi] * src1[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp191;
fp191 = inteval->PA_z[vi] * src0[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp189;
fp189 = fp191 + fp190;
LIBINT2_REALTYPE fp187;
fp187 = fp189 + fp188;
target[((hsi*60+33)*1+lsi)*1] = fp187;
LIBINT2_REALTYPE fp193;
fp193 = inteval->oo2ze[vi] * src4[((hsi*18+6)*1+lsi)*1];
LIBINT2_REALTYPE fp195;
fp195 = inteval->oo2z[vi] * fp349;
LIBINT2_REALTYPE fp197;
fp197 = inteval->WP_z[vi] * src1[((hsi*36+14)*1+lsi)*1];
LIBINT2_REALTYPE fp198;
fp198 = inteval->PA_z[vi] * src0[((hsi*36+14)*1+lsi)*1];
LIBINT2_REALTYPE fp196;
fp196 = fp198 + fp197;
LIBINT2_REALTYPE fp194;
fp194 = fp196 + fp195;
LIBINT2_REALTYPE fp192;
fp192 = fp194 + fp193;
target[((hsi*60+32)*1+lsi)*1] = fp192;
LIBINT2_REALTYPE fp200;
fp200 = inteval->oo2z[vi] * fp359;
LIBINT2_REALTYPE fp202;
fp202 = inteval->WP_z[vi] * src1[((hsi*36+13)*1+lsi)*1];
LIBINT2_REALTYPE fp203;
fp203 = inteval->PA_z[vi] * src0[((hsi*36+13)*1+lsi)*1];
LIBINT2_REALTYPE fp201;
fp201 = fp203 + fp202;
LIBINT2_REALTYPE fp199;
fp199 = fp201 + fp200;
target[((hsi*60+31)*1+lsi)*1] = fp199;
LIBINT2_REALTYPE fp205;
fp205 = inteval->oo2z[vi] * fp370;
LIBINT2_REALTYPE fp207;
fp207 = inteval->WP_z[vi] * src1[((hsi*36+12)*1+lsi)*1];
LIBINT2_REALTYPE fp208;
fp208 = inteval->PA_z[vi] * src0[((hsi*36+12)*1+lsi)*1];
LIBINT2_REALTYPE fp206;
fp206 = fp208 + fp207;
LIBINT2_REALTYPE fp204;
fp204 = fp206 + fp205;
target[((hsi*60+30)*1+lsi)*1] = fp204;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 376 */
}

#ifdef __cplusplus
};
#endif
